@@ -52,7 +52,7 @@ class ChatScriptRunner:
         inputs: List[str],
         *,
         console: Optional[Console] = None,
-        provider: str = "moonshotai",
+        provider: str = "moonshot",
         model: str = "kimi-k1-8k",
         use_real_agent: bool = True,
         **chat_session_kwargs,
