@@ -7,7 +7,14 @@ class HelpShellHandler(ShellCmdHandler):
     help_text = "Show this help message"
 
     def run(self):
-        from . import COMMAND_HANDLERS
+        # Ensure /provider command is registered before showing help
+        from janito.cli.chat_mode.shell.commands import COMMAND_HANDLERS
+
+        if "/provider" not in COMMAND_HANDLERS:
+            from janito.cli.chat_mode.shell.commands.provider import ProviderCmdHandler
+
+            COMMAND_HANDLERS["/provider"] = ProviderCmdHandler
+
         from ._priv_check import user_has_any_privileges
 
         shared_console.print("[bold magenta]Available commands:[/bold magenta]")
