@@ -1,3 +1,3 @@
 from rich.console import Console
 
-shared_console = Console()
+shared_console = Console(file=None)
