@@ -12,18 +12,20 @@ from janito.llm.driver_input import DriverInput
 from janito.driver_events import RequestFinished, RequestStatus, RateLimitRetry
 from janito.llm.message_parts import TextMessagePart, FunctionCallMessagePart
 
-try:
-    import openai
-    available = True
-    unavailable_reason = None
-except ImportError:
-    available = False
-    unavailable_reason = "openai module not installed"
+import openai
 
 
 class ZAIModelDriver(LLMDriver):
-    available = available
-    unavailable_reason = unavailable_reason
+    # Check if required dependencies are available
+    try:
+        from zai import ZaiClient
+
+        available = True
+        unavailable_reason = None
+    except ImportError as e:
+        available = False
+        unavailable_reason = f"Missing dependency: {str(e)}"
+
     def _get_message_from_result(self, result):
         """Extract the message object from the provider result (Z.AI-specific)."""
         if hasattr(result, "choices") and result.choices:
@@ -256,14 +258,11 @@ class ZAIModelDriver(LLMDriver):
         try:
             if not config.api_key:
                 provider_name = getattr(self, "provider_name", "ZAI")
-                print(
-                    f"[ERROR] No API key found for provider '{provider_name}'. Please set the API key using:"
+                from janito.llm.auth_utils import handle_missing_api_key
+
+                handle_missing_api_key(
+                    provider_name, f"{provider_name.upper()}_API_KEY"
                 )
-                print(f"  janito --set-api-key YOUR_API_KEY -p {provider_name.lower()}")
-                print(
-                    f"Or set the {provider_name.upper()}_API_KEY environment variable."
-                )
-                raise ValueError(f"API key is required for provider '{provider_name}'")
 
             api_key_display = str(config.api_key)
             if api_key_display and len(api_key_display) > 8:
@@ -284,12 +283,10 @@ class ZAIModelDriver(LLMDriver):
                     flush=True,
                 )
 
-            # Use OpenAI SDK for Z.AI API compatibility
-            try:
-                import openai
-            except ImportError:
-                raise ImportError("openai module is not available. Please install it with: pip install openai")
-            client = openai.OpenAI(
+            # Use the official Z.ai SDK
+            from zai import ZaiClient
+
+            client = ZaiClient(
                 api_key=config.api_key, base_url="https://api.z.ai/api/paas/v4/"
             )
             return client
