@@ -4,8 +4,9 @@ import janito.providers.google.provider
 import janito.providers.azure_openai.provider
 import janito.providers.anthropic.provider
 import janito.providers.deepseek.provider
-import janito.providers.moonshotai.provider
+import janito.providers.moonshot.provider
 import janito.providers.alibaba.provider
 import janito.providers.zai.provider
 import janito.providers.cerebras.provider
 import janito.providers.mistral.provider
+import janito.providers.ibm.provider
