@@ -17,7 +17,7 @@ class AlibabaProvider(LLMProvider):
     NAME = "alibaba"
     MAINTAINER = "João Pinto <janito@ikignosis.org>"
     MODEL_SPECS = MODEL_SPECS
-    DEFAULT_MODEL = "qwen3-235b-a22b-instruct-2507"  # 129k context, general-purpose model
+    DEFAULT_MODEL = "qwen3-max-preview"  # 128k context, latest preview model
 
     def __init__(
         self, auth_manager: LLMAuthManager = None, config: LLMDriverConfig = None
