@@ -33,11 +33,10 @@ class GoogleProvider(LLMProvider):
             self.auth_manager = auth_manager or LLMAuthManager()
             self._api_key = self.auth_manager.get_credentials(type(self).name)
             if not self._api_key:
-                print(f"[ERROR] No API key found for provider '{self.name}'. Please set the API key using:")
-                print(f"  janito --set-api-key YOUR_API_KEY -p {self.name}")
-                print(f"Or set the GOOGLE_API_KEY environment variable.")
-                return
-            
+                from janito.llm.auth_utils import handle_missing_api_key
+
+                handle_missing_api_key(self.name, "GOOGLE_API_KEY")
+
             self._tools_adapter = get_local_tools_adapter()
             self._driver_config = config or LLMDriverConfig(model=None)
             # Only set default if model is not set by CLI/config
