@@ -1,4 +1,4 @@
-from janito.tools.adapters.local import (
+from janito.plugins.tools.local import (
     local_tools_adapter as _internal_local_tools_adapter,
     LocalToolsAdapter,
 )
@@ -11,7 +11,7 @@ def get_local_tools_adapter(workdir=None, allowed_permissions=None):
     if workdir is not None and not os.path.exists(workdir):
         os.makedirs(workdir, exist_ok=True)
     # Permissions are now managed globally; ignore allowed_permissions argument except for backward compatibility
-    # Reuse the singleton adapter defined in janito.tools.adapters.local to maintain tool registrations
+    # Reuse the singleton adapter defined in janito.plugins.tools.local to maintain tool registrations
     registry = _internal_local_tools_adapter
     # Change workdir if requested
     if workdir is not None:
